@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: ag.c,v 3.3 1998/02/25 19:52:16 jt Exp $ */
+/* $Id: ag.c,v 3.4 1999/11/22 13:50:23 jt Exp $ */
 /* ag.c */
 
 #ifndef	SINGLEFILE
@@ -118,7 +120,7 @@ ag_eow(ARGVECTOR *ag)
 {
     if( ag->iw >= ag->c )
         return(TRUE);
-    if( ag->ic >= strlen(ag->v[ag->iw]) )
+    if( ag->ic >= (int)strlen(ag->v[ag->iw]) )
         return(TRUE);
     return(FALSE);
 }
@@ -184,17 +186,18 @@ ag_backword(ARGVECTOR *ag)
 char
 ag_backspace(ARGVECTOR *ag)
 {
-        if( --(ag->ic) < 0 )            /* if back past beginning of word */
-        {       ag->ic=0;
-                if(--(ag->iw) < 0)      /* goto beginning of previous word */
-                        ag_reset(ag);           /* if no previous, reset */
-                else
-                {       while( !ag_eow(ag) )    /* goto end of prevous word */
-                                ag_c_advance(ag);
-                        ag_backspace(ag);       /* back to just before end */
-                }
+    if( --(ag->ic) < 0 ) {          /* if back past beginning of word */
+        ag->ic=0;
+        if(--(ag->iw) < 0) {        /* goto beginning of previous word */
+            ag_reset(ag);           /* if no previous, reset */
         }
-        return(ag->v[ag->iw][ag->ic]);
+        else {
+            while( !ag_eow(ag) )    /* goto end of prevous word */
+                ag_c_advance(ag);
+            ag_backspace(ag);       /* back to just before end */
+        }
+    }
+    return(ag->v[ag->iw][ag->ic]);
 }
 /*      ag_s:   returns current string
                 returns "" if current position is at end of word
