@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt.h,v 3.6 1998/07/26 22:23:36 jt Exp $ */
+/* $Id: opt.h,v 3.10 1999/11/22 13:44:11 jt Exp $ */
 /* opt.h */
 /*
 	User Include File for options package
@@ -27,6 +29,15 @@
 #ifndef _OPT_H
 #define	_OPT_H 	/* Signal that this header file has been included */
 
+/***
+ * Enable linking with C++
+ ***/
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
+
 
 typedef enum    {
     OPT_NUL,
@@ -42,7 +53,8 @@ typedef enum    {
 } opt_TYPE;
 
 /* OPT_PFI is the ever popular: Pointer to Function returning an Integer */
-typedef	int (*OPT_PFI)();
+typedef	int (*OPT_PFI)(void);
+typedef int (*OPT_HOOK)(void *);
 typedef	int (*OPT_PFI_ARG)(int,char**);
 
 #define	OPT_EXT	".opt"	  /* standard options file extension */
@@ -90,7 +102,7 @@ extern int optregsb( void *, opt_TYPE,        char *, char * );
 /*    ARGUMENT LIST:  &var   OPT_INT   'c'   "name"  "Descript" */
 
 /*    ARGUMENTS:    "name"  hook "Descript" */
-extern int optexec( char *, OPT_PFI, char * );
+extern int optexec( char *, OPT_HOOK, char * );
 
 /* Using the following routines, one can specify features (such as
  * char, longname, descript) of the variable that were left out in the
@@ -102,13 +114,13 @@ extern void optchar(     void *,char);
 extern void optlongname( void *,char *);
 extern void optdescript( void *,char *);
 extern void opthelp(     void *,char *);
-extern void opthook(     void *,OPT_PFI);
+extern void opthook(     void *,OPT_HOOK);
 /* These functions use option number to identify which option */
 extern void optchar_n(     int,char);
 extern void optlongname_n( int,char *);
 extern void optdescript_n( int,char *);
 extern void opthelp_n(     int,char *);
-extern void opthook_n(     int,OPT_PFI);
+extern void opthook_n(     int,OPT_HOOK);
 
 /* optinvoked(&var) returns the number of times the option was invoked
  * on the command line.  This function is not used in the registering
@@ -152,169 +164,6 @@ extern void opt_fatal(char *);
 
 
 
-/* BEGIN_AUTOGENERATED */
-#define UINT OPT_UINT
-extern int optrega_UINT(unsigned int *v, char c, char *n, char *B);
-extern int optreg_UINT(unsigned int *v, char c, char *B);
-extern int optregc_UINT(unsigned int *v, char c);
-extern int optregs_UINT(unsigned int *v, char *n);
-extern int optregcb_UINT(unsigned int *v, char c, char *B);
-extern int optregsb_UINT(unsigned int *v, char *s, char *B);
-#define UNSINT OPT_UNSINT
-extern int optrega_UNSINT(unsigned int *v, char c, char *n, char *B);
-extern int optreg_UNSINT(unsigned int *v, char c, char *B);
-extern int optregc_UNSINT(unsigned int *v, char c);
-extern int optregs_UNSINT(unsigned int *v, char *n);
-extern int optregcb_UNSINT(unsigned int *v, char c, char *B);
-extern int optregsb_UNSINT(unsigned int *v, char *s, char *B);
-#define INTLEVEL OPT_INTLEVEL
-extern int optrega_INTLEVEL(int *v, char c, char *n, char *B);
-extern int optreg_INTLEVEL(int *v, char c, char *B);
-extern int optregc_INTLEVEL(int *v, char c);
-extern int optregs_INTLEVEL(int *v, char *n);
-extern int optregcb_INTLEVEL(int *v, char c, char *B);
-extern int optregsb_INTLEVEL(int *v, char *s, char *B);
-#define UNDELIMV OPT_UNDELIMV
-extern int optrega_UNDELIMV(char **v, char c, char *n, char *B);
-extern int optreg_UNDELIMV(char **v, char c, char *B);
-extern int optregc_UNDELIMV(char **v, char c);
-extern int optregs_UNDELIMV(char **v, char *n);
-extern int optregcb_UNDELIMV(char **v, char c, char *B);
-extern int optregsb_UNDELIMV(char **v, char *s, char *B);
-#define ULONG OPT_ULONG
-extern int optrega_ULONG(unsigned long *v, char c, char *n, char *B);
-extern int optreg_ULONG(unsigned long *v, char c, char *B);
-extern int optregc_ULONG(unsigned long *v, char c);
-extern int optregs_ULONG(unsigned long *v, char *n);
-extern int optregcb_ULONG(unsigned long *v, char c, char *B);
-extern int optregsb_ULONG(unsigned long *v, char *s, char *B);
-#define USHORT OPT_USHORT
-extern int optrega_USHORT(unsigned short *v, char c, char *n, char *B);
-extern int optreg_USHORT(unsigned short *v, char c, char *B);
-extern int optregc_USHORT(unsigned short *v, char c);
-extern int optregs_USHORT(unsigned short *v, char *n);
-extern int optregcb_USHORT(unsigned short *v, char c, char *B);
-extern int optregsb_USHORT(unsigned short *v, char *s, char *B);
-#define ABSNEGFLAG OPT_ABSNEGFLAG
-extern int optrega_ABSNEGFLAG(int *v, char c, char *n, char *B);
-extern int optreg_ABSNEGFLAG(int *v, char c, char *B);
-extern int optregc_ABSNEGFLAG(int *v, char c);
-extern int optregs_ABSNEGFLAG(int *v, char *n);
-extern int optregcb_ABSNEGFLAG(int *v, char c, char *B);
-extern int optregsb_ABSNEGFLAG(int *v, char *s, char *B);
-#define INT OPT_INT
-extern int optrega_INT(int *v, char c, char *n, char *B);
-extern int optreg_INT(int *v, char c, char *B);
-extern int optregc_INT(int *v, char c);
-extern int optregs_INT(int *v, char *n);
-extern int optregcb_INT(int *v, char c, char *B);
-extern int optregsb_INT(int *v, char *s, char *B);
-#define VSTRING OPT_VSTRING
-extern int optrega_VSTRING(char **v, char c, char *n, char *B);
-extern int optreg_VSTRING(char **v, char c, char *B);
-extern int optregc_VSTRING(char **v, char c);
-extern int optregs_VSTRING(char **v, char *n);
-extern int optregcb_VSTRING(char **v, char c, char *B);
-extern int optregsb_VSTRING(char **v, char *s, char *B);
-#define UNDELIM OPT_UNDELIM
-extern int optrega_UNDELIM(char **v, char c, char *n, char *B);
-extern int optreg_UNDELIM(char **v, char c, char *B);
-extern int optregc_UNDELIM(char **v, char c);
-extern int optregs_UNDELIM(char **v, char *n);
-extern int optregcb_UNDELIM(char **v, char c, char *B);
-extern int optregsb_UNDELIM(char **v, char *s, char *B);
-#define NUL OPT_NUL
-extern int optrega_NUL(void *v, char c, char *n, char *B);
-extern int optreg_NUL(void *v, char c, char *B);
-extern int optregc_NUL(void *v, char c);
-extern int optregs_NUL(void *v, char *n);
-extern int optregcb_NUL(void *v, char c, char *B);
-extern int optregsb_NUL(void *v, char *s, char *B);
-#define SHORT OPT_SHORT
-extern int optrega_SHORT(short *v, char c, char *n, char *B);
-extern int optreg_SHORT(short *v, char c, char *B);
-extern int optregc_SHORT(short *v, char c);
-extern int optregs_SHORT(short *v, char *n);
-extern int optregcb_SHORT(short *v, char c, char *B);
-extern int optregsb_SHORT(short *v, char *s, char *B);
-#define LONG OPT_LONG
-extern int optrega_LONG(long *v, char c, char *n, char *B);
-extern int optreg_LONG(long *v, char c, char *B);
-extern int optregc_LONG(long *v, char c);
-extern int optregs_LONG(long *v, char *n);
-extern int optregcb_LONG(long *v, char c, char *B);
-extern int optregsb_LONG(long *v, char *s, char *B);
-#define ABSFLAG OPT_ABSFLAG
-extern int optrega_ABSFLAG(int *v, char c, char *n, char *B);
-extern int optreg_ABSFLAG(int *v, char c, char *B);
-extern int optregc_ABSFLAG(int *v, char c);
-extern int optregs_ABSFLAG(int *v, char *n);
-extern int optregcb_ABSFLAG(int *v, char c, char *B);
-extern int optregsb_ABSFLAG(int *v, char *s, char *B);
-#define UNDELIMC OPT_UNDELIMC
-extern int optrega_UNDELIMC(char *v, char c, char *n, char *B);
-extern int optreg_UNDELIMC(char *v, char c, char *B);
-extern int optregc_UNDELIMC(char *v, char c);
-extern int optregs_UNDELIMC(char *v, char *n);
-extern int optregcb_UNDELIMC(char *v, char c, char *B);
-extern int optregsb_UNDELIMC(char *v, char *s, char *B);
-#define UCHAR OPT_UCHAR
-extern int optrega_UCHAR(unsigned char *v, char c, char *n, char *B);
-extern int optreg_UCHAR(unsigned char *v, char c, char *B);
-extern int optregc_UCHAR(unsigned char *v, char c);
-extern int optregs_UCHAR(unsigned char *v, char *n);
-extern int optregcb_UCHAR(unsigned char *v, char c, char *B);
-extern int optregsb_UCHAR(unsigned char *v, char *s, char *B);
-#define NEGFLAG OPT_NEGFLAG
-extern int optrega_NEGFLAG(int *v, char c, char *n, char *B);
-extern int optreg_NEGFLAG(int *v, char c, char *B);
-extern int optregc_NEGFLAG(int *v, char c);
-extern int optregs_NEGFLAG(int *v, char *n);
-extern int optregcb_NEGFLAG(int *v, char c, char *B);
-extern int optregsb_NEGFLAG(int *v, char *s, char *B);
-#define FLOAT OPT_FLOAT
-extern int optrega_FLOAT(float *v, char c, char *n, char *B);
-extern int optreg_FLOAT(float *v, char c, char *B);
-extern int optregc_FLOAT(float *v, char c);
-extern int optregs_FLOAT(float *v, char *n);
-extern int optregcb_FLOAT(float *v, char c, char *B);
-extern int optregsb_FLOAT(float *v, char *s, char *B);
-#define STRING OPT_STRING
-extern int optrega_STRING(char **v, char c, char *n, char *B);
-extern int optreg_STRING(char **v, char c, char *B);
-extern int optregc_STRING(char **v, char c);
-extern int optregs_STRING(char **v, char *n);
-extern int optregcb_STRING(char **v, char c, char *B);
-extern int optregsb_STRING(char **v, char *s, char *B);
-#define CSTRING OPT_CSTRING
-extern int optrega_CSTRING(char *v, char c, char *n, char *B);
-extern int optreg_CSTRING(char *v, char c, char *B);
-extern int optregc_CSTRING(char *v, char c);
-extern int optregs_CSTRING(char *v, char *n);
-extern int optregcb_CSTRING(char *v, char c, char *B);
-extern int optregsb_CSTRING(char *v, char *s, char *B);
-#define FLAG OPT_FLAG
-extern int optrega_FLAG(int *v, char c, char *n, char *B);
-extern int optreg_FLAG(int *v, char c, char *B);
-extern int optregc_FLAG(int *v, char c);
-extern int optregs_FLAG(int *v, char *n);
-extern int optregcb_FLAG(int *v, char c, char *B);
-extern int optregsb_FLAG(int *v, char *s, char *B);
-#define DOUBLE OPT_DOUBLE
-extern int optrega_DOUBLE(double *v, char c, char *n, char *B);
-extern int optreg_DOUBLE(double *v, char c, char *B);
-extern int optregc_DOUBLE(double *v, char c);
-extern int optregs_DOUBLE(double *v, char *n);
-extern int optregcb_DOUBLE(double *v, char c, char *B);
-extern int optregsb_DOUBLE(double *v, char *s, char *B);
-#define CHAR OPT_CHAR
-extern int optrega_CHAR(char *v, char c, char *n, char *B);
-extern int optreg_CHAR(char *v, char c, char *B);
-extern int optregc_CHAR(char *v, char c);
-extern int optregs_CHAR(char *v, char *n);
-extern int optregcb_CHAR(char *v, char c, char *B);
-extern int optregsb_CHAR(char *v, char *s, char *B);
-/* END_AUTOGENERATED */
 
 /* The following prototypes are deprecated; they are defined for
  * compatibility with versions of opt prior to v3.0, but they are not
@@ -324,6 +173,224 @@ extern  int getopts(int,char **);
 #define	optregister(val,typ,c,str) optreg(&val,typ,c,str)
 #define optrunset(r) do {int r(); opt_run_set(r);} while(0)
 
+#ifdef __cplusplus
+}
+#endif
+
+/* BEGIN_AUTOGENERATED */
+#ifdef __cplusplus
+extern "C" {
+#endif
+#define UINT OPT_UINT /* ...but use the OPT_UINT */
+extern int optrega_UINT(unsigned int *v, char c, char *n, char *B);
+extern int optreg_UINT(unsigned int *v, char c, char *B);
+extern int optregc_UINT(unsigned int *v, char c);
+extern int optregs_UINT(unsigned int *v, char *n);
+extern int optregcb_UINT(unsigned int *v, char c, char *B);
+extern int optregsb_UINT(unsigned int *v, char *s, char *B);
+#define UNSINT OPT_UNSINT /* ...but use the OPT_UNSINT */
+extern int optrega_UNSINT(unsigned int *v, char c, char *n, char *B);
+extern int optreg_UNSINT(unsigned int *v, char c, char *B);
+extern int optregc_UNSINT(unsigned int *v, char c);
+extern int optregs_UNSINT(unsigned int *v, char *n);
+extern int optregcb_UNSINT(unsigned int *v, char c, char *B);
+extern int optregsb_UNSINT(unsigned int *v, char *s, char *B);
+#define INTLEVEL OPT_INTLEVEL /* ...but use the OPT_INTLEVEL */
+extern int optrega_INTLEVEL(int *v, char c, char *n, char *B);
+extern int optreg_INTLEVEL(int *v, char c, char *B);
+extern int optregc_INTLEVEL(int *v, char c);
+extern int optregs_INTLEVEL(int *v, char *n);
+extern int optregcb_INTLEVEL(int *v, char c, char *B);
+extern int optregsb_INTLEVEL(int *v, char *s, char *B);
+#define UNDELIMV OPT_UNDELIMV /* ...but use the OPT_UNDELIMV */
+extern int optrega_UNDELIMV(char **v, char c, char *n, char *B);
+extern int optreg_UNDELIMV(char **v, char c, char *B);
+extern int optregc_UNDELIMV(char **v, char c);
+extern int optregs_UNDELIMV(char **v, char *n);
+extern int optregcb_UNDELIMV(char **v, char c, char *B);
+extern int optregsb_UNDELIMV(char **v, char *s, char *B);
+#define USHORT OPT_USHORT /* ...but use the OPT_USHORT */
+extern int optrega_USHORT(unsigned short *v, char c, char *n, char *B);
+extern int optreg_USHORT(unsigned short *v, char c, char *B);
+extern int optregc_USHORT(unsigned short *v, char c);
+extern int optregs_USHORT(unsigned short *v, char *n);
+extern int optregcb_USHORT(unsigned short *v, char c, char *B);
+extern int optregsb_USHORT(unsigned short *v, char *s, char *B);
+#define ULONG OPT_ULONG /* ...but use the OPT_ULONG */
+extern int optrega_ULONG(unsigned long *v, char c, char *n, char *B);
+extern int optreg_ULONG(unsigned long *v, char c, char *B);
+extern int optregc_ULONG(unsigned long *v, char c);
+extern int optregs_ULONG(unsigned long *v, char *n);
+extern int optregcb_ULONG(unsigned long *v, char c, char *B);
+extern int optregsb_ULONG(unsigned long *v, char *s, char *B);
+#define ABSNEGFLAG OPT_ABSNEGFLAG /* ...but use the OPT_ABSNEGFLAG */
+extern int optrega_ABSNEGFLAG(int *v, char c, char *n, char *B);
+extern int optreg_ABSNEGFLAG(int *v, char c, char *B);
+extern int optregc_ABSNEGFLAG(int *v, char c);
+extern int optregs_ABSNEGFLAG(int *v, char *n);
+extern int optregcb_ABSNEGFLAG(int *v, char c, char *B);
+extern int optregsb_ABSNEGFLAG(int *v, char *s, char *B);
+#define INT OPT_INT /* ...but use the OPT_INT */
+extern int optrega_INT(int *v, char c, char *n, char *B);
+extern int optreg_INT(int *v, char c, char *B);
+extern int optregc_INT(int *v, char c);
+extern int optregs_INT(int *v, char *n);
+extern int optregcb_INT(int *v, char c, char *B);
+extern int optregsb_INT(int *v, char *s, char *B);
+#define VSTRING OPT_VSTRING /* ...but use the OPT_VSTRING */
+extern int optrega_VSTRING(char **v, char c, char *n, char *B);
+extern int optreg_VSTRING(char **v, char c, char *B);
+extern int optregc_VSTRING(char **v, char c);
+extern int optregs_VSTRING(char **v, char *n);
+extern int optregcb_VSTRING(char **v, char c, char *B);
+extern int optregsb_VSTRING(char **v, char *s, char *B);
+#define UNDELIM OPT_UNDELIM /* ...but use the OPT_UNDELIM */
+extern int optrega_UNDELIM(char **v, char c, char *n, char *B);
+extern int optreg_UNDELIM(char **v, char c, char *B);
+extern int optregc_UNDELIM(char **v, char c);
+extern int optregs_UNDELIM(char **v, char *n);
+extern int optregcb_UNDELIM(char **v, char c, char *B);
+extern int optregsb_UNDELIM(char **v, char *s, char *B);
+#define NUL OPT_NUL /* ...but use the OPT_NUL */
+extern int optrega_NUL(void *v, char c, char *n, char *B);
+extern int optreg_NUL(void *v, char c, char *B);
+extern int optregc_NUL(void *v, char c);
+extern int optregs_NUL(void *v, char *n);
+extern int optregcb_NUL(void *v, char c, char *B);
+extern int optregsb_NUL(void *v, char *s, char *B);
+#define LONG OPT_LONG /* ...but use the OPT_LONG */
+extern int optrega_LONG(long *v, char c, char *n, char *B);
+extern int optreg_LONG(long *v, char c, char *B);
+extern int optregc_LONG(long *v, char c);
+extern int optregs_LONG(long *v, char *n);
+extern int optregcb_LONG(long *v, char c, char *B);
+extern int optregsb_LONG(long *v, char *s, char *B);
+#define SHORT OPT_SHORT /* ...but use the OPT_SHORT */
+extern int optrega_SHORT(short *v, char c, char *n, char *B);
+extern int optreg_SHORT(short *v, char c, char *B);
+extern int optregc_SHORT(short *v, char c);
+extern int optregs_SHORT(short *v, char *n);
+extern int optregcb_SHORT(short *v, char c, char *B);
+extern int optregsb_SHORT(short *v, char *s, char *B);
+#define ABSFLAG OPT_ABSFLAG /* ...but use the OPT_ABSFLAG */
+extern int optrega_ABSFLAG(int *v, char c, char *n, char *B);
+extern int optreg_ABSFLAG(int *v, char c, char *B);
+extern int optregc_ABSFLAG(int *v, char c);
+extern int optregs_ABSFLAG(int *v, char *n);
+extern int optregcb_ABSFLAG(int *v, char c, char *B);
+extern int optregsb_ABSFLAG(int *v, char *s, char *B);
+#define UNDELIMC OPT_UNDELIMC /* ...but use the OPT_UNDELIMC */
+extern int optrega_UNDELIMC(char *v, char c, char *n, char *B);
+extern int optreg_UNDELIMC(char *v, char c, char *B);
+extern int optregc_UNDELIMC(char *v, char c);
+extern int optregs_UNDELIMC(char *v, char *n);
+extern int optregcb_UNDELIMC(char *v, char c, char *B);
+extern int optregsb_UNDELIMC(char *v, char *s, char *B);
+#define UCHAR OPT_UCHAR /* ...but use the OPT_UCHAR */
+extern int optrega_UCHAR(unsigned char *v, char c, char *n, char *B);
+extern int optreg_UCHAR(unsigned char *v, char c, char *B);
+extern int optregc_UCHAR(unsigned char *v, char c);
+extern int optregs_UCHAR(unsigned char *v, char *n);
+extern int optregcb_UCHAR(unsigned char *v, char c, char *B);
+extern int optregsb_UCHAR(unsigned char *v, char *s, char *B);
+#define NEGFLAG OPT_NEGFLAG /* ...but use the OPT_NEGFLAG */
+extern int optrega_NEGFLAG(int *v, char c, char *n, char *B);
+extern int optreg_NEGFLAG(int *v, char c, char *B);
+extern int optregc_NEGFLAG(int *v, char c);
+extern int optregs_NEGFLAG(int *v, char *n);
+extern int optregcb_NEGFLAG(int *v, char c, char *B);
+extern int optregsb_NEGFLAG(int *v, char *s, char *B);
+#define FLOAT OPT_FLOAT /* ...but use the OPT_FLOAT */
+extern int optrega_FLOAT(float *v, char c, char *n, char *B);
+extern int optreg_FLOAT(float *v, char c, char *B);
+extern int optregc_FLOAT(float *v, char c);
+extern int optregs_FLOAT(float *v, char *n);
+extern int optregcb_FLOAT(float *v, char c, char *B);
+extern int optregsb_FLOAT(float *v, char *s, char *B);
+#define STRING OPT_STRING /* ...but use the OPT_STRING */
+extern int optrega_STRING(char **v, char c, char *n, char *B);
+extern int optreg_STRING(char **v, char c, char *B);
+extern int optregc_STRING(char **v, char c);
+extern int optregs_STRING(char **v, char *n);
+extern int optregcb_STRING(char **v, char c, char *B);
+extern int optregsb_STRING(char **v, char *s, char *B);
+#define FLAG OPT_FLAG /* ...but use the OPT_FLAG */
+extern int optrega_FLAG(int *v, char c, char *n, char *B);
+extern int optreg_FLAG(int *v, char c, char *B);
+extern int optregc_FLAG(int *v, char c);
+extern int optregs_FLAG(int *v, char *n);
+extern int optregcb_FLAG(int *v, char c, char *B);
+extern int optregsb_FLAG(int *v, char *s, char *B);
+#define CSTRING OPT_CSTRING /* ...but use the OPT_CSTRING */
+extern int optrega_CSTRING(char *v, char c, char *n, char *B);
+extern int optreg_CSTRING(char *v, char c, char *B);
+extern int optregc_CSTRING(char *v, char c);
+extern int optregs_CSTRING(char *v, char *n);
+extern int optregcb_CSTRING(char *v, char c, char *B);
+extern int optregsb_CSTRING(char *v, char *s, char *B);
+#define DOUBLE OPT_DOUBLE /* ...but use the OPT_DOUBLE */
+extern int optrega_DOUBLE(double *v, char c, char *n, char *B);
+extern int optreg_DOUBLE(double *v, char c, char *B);
+extern int optregc_DOUBLE(double *v, char c);
+extern int optregs_DOUBLE(double *v, char *n);
+extern int optregcb_DOUBLE(double *v, char c, char *B);
+extern int optregsb_DOUBLE(double *v, char *s, char *B);
+#define CHAR OPT_CHAR /* ...but use the OPT_CHAR */
+extern int optrega_CHAR(char *v, char c, char *n, char *B);
+extern int optreg_CHAR(char *v, char c, char *B);
+extern int optregc_CHAR(char *v, char c);
+extern int optregs_CHAR(char *v, char *n);
+extern int optregcb_CHAR(char *v, char c, char *B);
+extern int optregsb_CHAR(char *v, char *s, char *B);
+#ifdef __cplusplus
+}
+/* OptRegister() only available on C++ systems */
+extern int OptRegister(unsigned int *v, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned int *v, char *n, char *B=0);
+extern int OptRegister(unsigned int *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned int *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(long *v, char c, char *n=0, char *B=0);
+extern int OptRegister(long *v, char *n, char *B=0);
+extern int OptRegister(long *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(long *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(short *v, char c, char *n=0, char *B=0);
+extern int OptRegister(short *v, char *n, char *B=0);
+extern int OptRegister(short *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(short *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(unsigned char *v, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned char *v, char *n, char *B=0);
+extern int OptRegister(unsigned char *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned char *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(unsigned long *v, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned long *v, char *n, char *B=0);
+extern int OptRegister(unsigned long *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned long *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(unsigned short *v, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned short *v, char *n, char *B=0);
+extern int OptRegister(unsigned short *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(unsigned short *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(float *v, char c, char *n=0, char *B=0);
+extern int OptRegister(float *v, char *n, char *B=0);
+extern int OptRegister(float *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(float *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(char **v, char c, char *n=0, char *B=0);
+extern int OptRegister(char **v, char *n, char *B=0);
+extern int OptRegister(char **v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(char **v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(int *v, char c, char *n=0, char *B=0);
+extern int OptRegister(int *v, char *n, char *B=0);
+extern int OptRegister(int *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(int *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(double *v, char c, char *n=0, char *B=0);
+extern int OptRegister(double *v, char *n, char *B=0);
+extern int OptRegister(double *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(double *v, opt_TYPE o, char *n, char *B=0);
+extern int OptRegister(char *v, char c, char *n=0, char *B=0);
+extern int OptRegister(char *v, char *n, char *B=0);
+extern int OptRegister(char *v, opt_TYPE o, char c, char *n=0, char *B=0);
+extern int OptRegister(char *v, opt_TYPE o, char *n, char *B=0);
+#endif /* __cplusplus */
+/* END_AUTOGENERATED */
 
 #endif /* _OPT_H */
 
