@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt_menu.c,v 3.1 1997/10/24 22:35:08 jt Exp $ */
+/* $Id: opt_menu.c,v 3.2 1999/11/22 13:50:23 jt Exp $ */
 /* opt_menu.c */
 
 
@@ -46,7 +48,6 @@ flag menuflag=False;
 static char mgstring[160];	/* global menu string */
 
 #define menu_wr_string(str)       opt_message(str)
-#define menu_getresponse(respond) opt_getline(respond,stdin)
 
 static void write_the_menu(int iopfrom, int iopto);
 static int auto_prefix_delim(char *r);
@@ -60,7 +61,8 @@ static int auto_prefix_delim(char *r);
 #ifndef	MAXOPTSINMENU
 #define	MAXOPTSINMENU	20
 #endif
-#define MENUPROMPT "-> "
+
+char *MENUPROMPT="-> ";
 
 void
 opt_menu(void)
@@ -80,7 +82,7 @@ opt_menu(void)
     write_the_menu(iopfrom,iopto);
 
     while( menuflag ) {
-        opt_menu_getresponse(MENUPROMPT,respond,MAXRESPONDLINE);
+        opt_menu_getline(MENUPROMPT,respond,MAXRESPONDLINE);
 		
         switch(*respond) {
         case ADDITIONAL_OPTS:
