@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt_p.h,v 3.5 1998/07/01 16:56:34 jt Exp $ */
+/* $Id: opt_p.h,v 3.6 1999/11/22 13:50:24 jt Exp $ */
 /* opt_p.h */
 /*
  *	Private header file for OPT package.
@@ -27,6 +29,14 @@
 #ifndef _OPT_P_H
 #define _OPT_P_H
 
+/***
+ * Enable linking with C++
+ ***/
+#ifdef __cplusplus
+extern "C"
+{
+#endif
+
 #ifndef	OPT_TRUE
 #define	OPT_TRUE	1
 #define	OPT_FALSE	0
@@ -110,7 +120,7 @@ extern  int        opt_undelim(ARGVECTOR *);
 extern  int        opt_delim(ARGVECTOR *);
 extern  int        opt_lineprocess(char *);
 extern	void	   opt_menu(void);
-extern  void       opt_menu_getresponse(char *, char *, int);
+extern  void       opt_menu_getline(char *, char *, int);
 
 extern	void	opt_help(char *);
 extern	void	opt_quit(void);
@@ -151,12 +161,27 @@ extern  void    opt_readline_init(char *);
 	opt_fatal(gstr); } while(0)
 
 
+/* ...well, assume that you do have strdup, since if you do and you
+ * say you don't you can get into trouble.  if you really don't, you
+ * should '#define HAVE_STRDUP 0' (or -DHAVE_STRDUP=0 on command line)
+ */
 #ifndef HAVE_STRDUP
-#define HAVE_STRDUP 0
+#define HAVE_STRDUP 1
 #endif
 
 #if !HAVE_STRDUP
 char *strdup(char *s);
 #endif
 
+/***
+ * Enable linking with C++
+ ***/
+#ifdef __cplusplus
+}
+#endif
 #endif /* _OPT_P_H */
+
+
+
+
+
