@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt_proc.c,v 3.7 1998/07/25 19:45:11 jt Exp $ */
+/* $Id: opt_proc.c,v 3.9 1999/11/19 17:46:57 jt Exp $ */
 /* opt_proc.c */
 /*
  *	process options in the OPT package
@@ -162,8 +164,6 @@ getopts(int argc, char **argv)
     /* Second, check environment variable */
     if(opt_envstring != NULL) {
 	char	*s;
-	char	*getenv(const char *);
-	
 	s = getenv(opt_envstring);
 	opt_lineprocess(s);
     }
@@ -502,6 +502,7 @@ opt_process(int argc, char **argv)
             }
         }
     }
+    ag_free(ag);
     return (ARGVECTOR *)NULL;
 }/*opt_process*/
 
@@ -521,6 +522,8 @@ opt_lineprocess(char *line)
  
     line2argv(&nargc,&nargv,line);
     opt_process(nargc,nargv);
+    /* at this point, we leak the copy of doubly-terminated
+     * line we made in line2argv */
     return(nargc);
 }
 /*	line2argv(): converts a one-line string into an argument vector */
@@ -528,7 +531,7 @@ opt_lineprocess(char *line)
 static int
 line2argv(int *pargc, char ***pargv, char *line)
 {
-    char	*lincp;
+    char *lincp;
     if(line==NULL) {	
 	*pargc = 0;
 	**pargv = NULL;
@@ -701,6 +704,7 @@ backup_file(char *fname)
     opt_mess_1("Options file [%s] has been overwritten\n",fname_bak);
     fclose(fp_bak);
     fclose(fp);
+    free((char *)fname_bak);    /* allocated in append_string */
     return 0;                   /* success */                   
 }
 
