@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt_reg.c,v 3.12 1998/07/26 22:25:03 jt Exp $ */
+/* $Id: opt_reg.c,v 3.15 1999/11/22 13:50:24 jt Exp $ */
 /* opt_reg.c */
 
 /************************ register options ********************************
@@ -87,9 +89,7 @@ static int opt_longname_number(char *);
 static int opt_valid_longname(char *);
 #endif
 
-static char blankstringval = '\0';
-#define BLANKSTRING (&blankstringval) /* non-null blank string */
-#define ISVALIDNUMBER(n) ((n)>=0 && (n)<opt_nreg)
+#define ISVALIDOPTN(n) ((n)>=0 && (n)<opt_nreg)
 
 int opt_exit_number=0;          /* if we have to exit(), then exit
                                  * with this number.
@@ -109,7 +109,7 @@ typedef struct {
     char      *descript;      /* a brief description */
     char      *help;          /* longer help message */
     int        invoked;       /* flag is set to 1 if option is invoked */
-    OPT_PFI    hook;          /* code to evaluate if option is invoked */
+    OPT_HOOK   hook;          /* code to evaluate if option is invoked */
 }   EACH_OPT;
 
 static	EACH_OPT optlist[MAXOPTS];               /* array of options */
@@ -135,7 +135,7 @@ int              opt_nreg=0;                     /* number of registered opts */
 
 #define SETOPTVALUE(typ,i,val)  { typ *xptr;                     \
                                   xptr = (typ *)(optlist[i].value); \
-                                  *xptr = val; }
+                                  *xptr = (typ)val; }
 
         /* ------------------------------- */
         /* Routine to register each option */
@@ -156,7 +156,7 @@ int optregs(void *val, opt_TYPE otype, char *longname) {
 int optregsb(void *val, opt_TYPE otype, char *longname, char *descript) {
     return optrega(val,otype,'\0',longname,descript);
 }
-int optexec(char *longname, OPT_PFI fcn, char *descript)
+int optexec(char *longname, OPT_HOOK fcn, char *descript)
 {
     int n;
     n = optrega(NULL,OPT_NUL,'\0',longname,descript);
@@ -167,18 +167,6 @@ int optexec(char *longname, OPT_PFI fcn, char *descript)
 int
 optrega(void *val, opt_TYPE otype, char name, char *longname, char *descript)
 {
-    char *thename=BLANKSTRING;
-
-    if (name != '\0') {
-        thename = strdup(".");
-        thename[0] = name;
-        thename[1] = '\0';
-    } else if (!ISEMPTYSTRING(longname)) {
-        thename = strdup(longname);
-    } else if (!ISEMPTYSTRING(descript)) {
-        thename = strdup(descript);
-    }
-    
     if( opt_nreg >= MAXOPTS )
         opt_fatal("optrega: too many options");
 	
@@ -230,27 +218,27 @@ optrega(void *val, opt_TYPE otype, char name, char *longname, char *descript)
 }
 void optchar_n(int n, char name)
 {
-    if (ISVALIDNUMBER(n)) optlist[n].name = name;
+    if (ISVALIDOPTN(n)) optlist[n].name = name;
 }    
 void optdescript_n(int n, char *descript)
 {
-    if (ISVALIDNUMBER(n)) optlist[n].descript = strdup(descript);
+    if (ISVALIDOPTN(n)) optlist[n].descript = strdup(descript);
 }
 void opthelp_n(int n, char *help)
 {
-    if (ISVALIDNUMBER(n)) optlist[n].help = strdup(help);
+    if (ISVALIDOPTN(n)) optlist[n].help = strdup(help);
 }
 void optlongname_n(int n, char *longname)
 {
-    if (ISVALIDNUMBER(n)) optlist[n].longname = strdup(longname);
+    if (ISVALIDOPTN(n)) optlist[n].longname = strdup(longname);
 }
-void opthook_n(int n, OPT_PFI hook)
+void opthook_n(int n, OPT_HOOK hook)
 {
-    if (ISVALIDNUMBER(n)) optlist[n].hook = hook;
+    if (ISVALIDOPTN(n)) optlist[n].hook = hook;
 }
 int optinvoked_n(int n)
 {
-    if (ISVALIDNUMBER(n))
+    if (ISVALIDOPTN(n))
         return optlist[n].invoked;
     return 0;
 }
@@ -259,7 +247,7 @@ int optinvoked(void *v) { return optinvoked_n( opt_number(v) ); }
 
 void optchar(void *v,  char name) { optchar_n( opt_number(v),   name ); }
 void opthelp(void *v,  char *help) { opthelp_n( opt_number(v),  help ); }
-void opthook(void *v,  OPT_PFI hook) { opthook_n( opt_number(v), hook ); }      
+void opthook(void *v,  OPT_HOOK hook) { opthook_n( opt_number(v), hook ); }      
 void optlongname(void *v, char *longname)
 {
     optlongname_n( opt_number(v), longname );
@@ -289,7 +277,7 @@ opt_get_help(char c)
 {
     int n;
     n = opt_char_number(c);
-    if (ISVALIDNUMBER(n) && optlist[n].help != NULL)
+    if (ISVALIDOPTN(n) && optlist[n].help != NULL)
         opt_mess_2("%c: %s\n",c,optlist[n].help);
     else
         opt_mess_1("Help unavailable for \'%c\'\n",c);
@@ -577,7 +565,6 @@ opt_mstring(int i)
     static char mstring[180];
     char	flgstr[10];
     char	*s;
-    char	*optstrval(int i);
     char	*format = "%c %-40s %s";
     char        *lformat = "  --%s %*s%s";
 
@@ -709,7 +696,7 @@ opt_undelim(ARGVECTOR *ag)
     for (i=0; i<opt_nreg; ++i) {
         if (optlist[i].invoked) continue;
         if (optlist[i].type==OPT_UNDELIMC ) {
-            strncpy( optlist[i].value, s , OPT_MAXSTRLEN);
+            strncpy( (char *)optlist[i].value, s , OPT_MAXSTRLEN);
             optlist[i].invoked += 1;
             return 1; /* success */
         }
@@ -737,7 +724,7 @@ opt_delim(ARGVECTOR *ag)
     c = ag_c_advance(ag);   /* first character gives name of option */
     i = opt_char_number(c);      /* this is number of option w/ name 'c' */
  
-    if(! ISVALIDNUMBER(i)) { /* if invalid option name */
+    if(! ISVALIDOPTN(i)) { /* if invalid option name */
         opt_warn_1("%c not a registered option name\n",c);
         return 0;
     }
@@ -766,11 +753,11 @@ opt_longdelim(ARGVECTOR *ag)
     }
     
     i  = opt_longname_number(sc);   /* this is number of option w/ name `sc' */
-    if(! ISVALIDNUMBER(i)) {
+    if(! ISVALIDOPTN(i)) {
         opt_warn_1("%s not a registered option name\n",sc);
         return 0;
     }
-
+    free((char *)sc); 
     return opt_action(i,ag);
 }
 
@@ -785,7 +772,7 @@ opt_action(int i, ARGVECTOR *ag)
     char      *s;
     int       yes,no,maybe,toggle;    /* flag values */
 
-    if (!ISVALIDNUMBER(i)) {
+    if (!ISVALIDOPTN(i)) {
         opt_warn_1("opt_action: invalid number %d\n",i);
         return 0; /* failure */
     }
@@ -930,3 +917,4 @@ opt_action(int i, ARGVECTOR *ag)
 
 
 
+
