@@ -1,24 +1,26 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
-/* $Id: opt_util.c,v 3.7 1998/07/01 16:56:39 jt Exp $ */
+/* $Id: opt_util.c,v 3.8 1999/11/22 13:50:24 jt Exp $ */
 /**************************
  *  some useful utilities *
  **************************/
@@ -43,6 +45,10 @@
  *  values should be set automatically by the system at configure time.
  */
 #ifndef SINGLEFILE
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -50,10 +56,14 @@
 #include "config.h"             /* supplies HAVE_VPRINTF + RETSIGTYPE */
 #endif
 #include "ag.h"
+#ifdef __cplusplus
+}
+#endif
 #include "opt.h"
 #include "opt_p.h"
 #endif /* SINGLEFILE */
 
+
 /* If these are not defined on the compile command line, then assume
  * the worst, that you don't have anything!
  */
@@ -66,6 +76,9 @@
 #ifndef RETSIGTYPE
 #define RETSIGTYPE void
 #endif
+#ifndef HAVE_READLINE
+#define HAVE_READLINE 0
+#endif
 
 /* Provide message/warning/fatal functions */
 /* Ordinary messages go to stdout, but warn/fatal messages to stderr;
@@ -209,25 +222,31 @@ void optAbortMain() { optAbortRun(); }
  * Readline *
  ************/
 
-#ifdef HAVE_READLINE
-#define READLINE_LIBRARY
+#if HAVE_READLINE
+#ifdef __cplusplus
+extern "C" {
 #include <readline/readline.h>
 #include <readline/history.h>
+}
+#else
+#include <readline/readline.h>
+#include <readline/history.h>
+#endif
 #endif
 
 void
 opt_readline_init(char *s)
 {
-#ifdef HAVE_READLINE
+#if HAVE_READLINE
     rl_readline_name = s;
 #endif
     return;
 }
 
 void 
-opt_menu_getresponse(char *prompt, char *respond, int maxlen)
+opt_menu_getline(char *prompt, char *respond, int maxlen)
 {
-#ifdef HAVE_READLINE
+#if HAVE_READLINE
     char *line;
     line = readline(prompt);
     if (line && *line) {
@@ -244,12 +263,6 @@ opt_menu_getresponse(char *prompt, char *respond, int maxlen)
 #endif
 }
 
-/* ...well, assume that you do have strdup, since if you do and you
- * say you don't you can get into trouble.
- */
-#ifndef HAVE_STRDUP
-#define HAVE_STRDUP 1
-#endif
 
 #if !HAVE_STRDUP
 /* Provided here in case it is not available on system */     
@@ -266,3 +279,9 @@ char *strdup(char *s)
 }
 #endif
     
+
+
+
+
+
+
