@@ -1,21 +1,23 @@
-/* OPT v3.7: options parsing tool */
+/* OPT v3.9: options parsing tool */
 /*
- * Copyright (C) 1998, James Theiler (jt@lanl.gov)
  * 
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ *     Copyright (C) 1996,1997,1998,1999 James Theiler 
  * 
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ *     This program is free software; you can redistribute it and/or modify
+ *     it under the terms of the GNU General Public License as published by
+ *     the Free Software Foundation; either version 2 of the License, or
+ *     (at your option) any later version.
+ * 
+ *     This program is distributed in the hope that it will be useful,
+ *     but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *     GNU General Public License for more details.
+ * 
+ *     You should have received a copy of the GNU General Public License
+ *     along with this program (it is in the file COPYING); if not, write 
+ *     to the Free Software Foundation, Inc., 
+ *            675 Mass Ave, Cambridge, MA 02139, USA.
  * 
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
  * 
  */
 /* testopt.c */
@@ -29,6 +31,7 @@ int day=24;
 int year=1993;
 int julian=0;
 char *who=NULL;
+int version=99;
 
 int go(int argc, char **argv)
 {
@@ -62,9 +65,11 @@ int quit()
     printf("Bye...\n");
     return OPT_OK;
 }
-int write_version()
+int write_version(void *v)
 {
-    printf("Version XXX\n");
+    /* it's a little hokey that this requires an argument... */
+    v = &version; 
+    printf("Version %d\n",version);
     optExitNumber(12);
     return OPT_EXIT;
 }
@@ -79,6 +84,7 @@ int fix_mon(void *v)
     return OPT_OK;
 } 
 
+int
 main(int argc, char **argv)
 {
     optreg(&month,OPT_INT,'m',"Month");
